@@ -90,9 +90,9 @@ class Spec(object):
                 self.functions[fname] = (signatures,)
 
         if not self:
-            import logging
-            logging.warning("No pythran specification, "
-                            "nothing will be exported")
+            from pythran.log import logger
+            logger.warning("No pythran specification, "
+                           "nothing will be exported")
 
     def keys(self):
         return list(self.functions.keys()) + list(self.capsules.keys())
@@ -281,9 +281,9 @@ class SpecParser(object):
                      | types'''
 
     def p_param_types(self, p):
-        if len(p) == 2:
+        if len(p) == 2 or (len(p) == 3 and p[2] == ','):
             p[0] = tuple((t,) for t in p[1])
-        elif len(p) == 3:
+        elif len(p) == 3 and p[2] == '?':
             p[0] = tuple((t,) for t in p[1]) + ((),)
         elif len(p) == 4:
             p[0] = tuple((t,) + ts for t in p[1] for ts in p[3])
@@ -292,6 +292,7 @@ class SpecParser(object):
 
     p_param_types.__doc__ = '''param_types : type
                        | type OPT
+                       | type COMMA
                        | type COMMA param_types
                        | type OPT COMMA default_types'''
 
@@ -443,7 +444,14 @@ class SpecParser(object):
         return err
 
     def p_error(self, p):
-        raise self.PythranSpecError("invalid pythran spec", p.lexpos)
+        if p.type == 'IDENTIFIER':
+            raise self.PythranSpecError(
+                "Unexpected identifier `{}` at that point".format(p.value),
+                p.lexpos)
+        else:
+            raise self.PythranSpecError(
+                "Unexpected token `{}` at that point".format(p.value),
+                p.lexpos)
 
     def __init__(self):
         self.lexer = lex.lex(module=self, debug=False)
@@ -542,6 +550,12 @@ def spec_parser(text):
     return SpecParser()(text)
 
 
+def parse_pytypes(s):
+    fake_def = '#pythran export fake({})'.format(s)
+    specs = SpecParser()(fake_def)
+    return specs.functions['fake'][0]
+
+
 def load_specfile(filepath):
     with open(filepath) as fd:
         return ExtraSpecParser()(fd.read(), input_file=filepath)
